@@ -15,5 +15,10 @@
 #
 # ##### END GPL LICENSE BLOCK #####
 
-from . import math
-from . import daily_uses
\ No newline at end of file
+from . import daily_uses
+from . import science
+
+print("""Python module SeanBlend
+Owner: SeanBlend <https://github.com/SeanBlend>
+Contributors:
+    Sean Huang <https://github.com/SeanBlend>""")
\ No newline at end of file
